@@ -8,8 +8,7 @@ from airflow.models import Variable
 
 @functools.lru_cache()
 def get_config(path=None, file="config.json"):
-    """Load the config for the current airflow environment.
-    """
+    """Load the config for the current airflow environment."""
     if path is None:
         path = configuration.get("core", "dags_folder")
 
@@ -26,6 +25,5 @@ def get_config(path=None, file="config.json"):
 
 
 def get_env():
-    """Get the name of the environment for the current airflow environment.
-    """
+    """Get the name of the environment for the current airflow environment."""
     return Variable.get("env")
